@@ -52,6 +52,7 @@
 #endif
 
 NPNetscapeFuncs NPNFuncs;
+#include <stddef.h>
 
 #ifdef XP_WIN
 
@@ -117,9 +118,23 @@ NPError OSCALL NP_Initialize(NPNetscapeFuncs * pFuncs
     if (HIBYTE(pFuncs->version) > NP_VERSION_MAJOR)
         return NPERR_INCOMPATIBLE_VERSION_ERROR;
 
-    if (pFuncs->size < sizeof(NPNetscapeFuncs))
+    // if (pFuncs->size < sizeof(NPNetscapeFuncs))
+    // Updated from Issue #184
+    // using model from http://sources.debian.net/src/iceweasel/21.0-1/dom/plugins/test/testplugin/nptest.cpp#L672
+    if (pFuncs->size < (offsetof(NPNetscapeFuncs, setexception) + sizeof(void *)))
         return NPERR_INVALID_FUNCTABLE_ERROR;
 
+#ifdef XP_UNIX
+#ifdef OIJ
+    if (pFuncs->size < (offsetof(NPPluginFuncs, javaClass) + sizeof(void *)))
+        return NPERR_INVALID_FUNCTABLE_ERROR;
+#else
+    if (pFuncs->size < (offsetof(NPPluginFuncs, getvalue) + sizeof(void *)))
+        return NPERR_INVALID_FUNCTABLE_ERROR;
+#endif
+#endif
+
+
     NPNFuncs.size = pFuncs->size;
     NPNFuncs.version = pFuncs->version;
     NPNFuncs.geturlnotify = pFuncs->geturlnotify;
